#!/usr/bin/env python
# -*- coding: iso-8859-15 -*-
# cherrypywithsubdirs.py

import os
import sys
import cherrypy
import subprocess
from Cheetah.Template import Template

APPDIR = os.path.dirname(os.path.abspath(__file__))
INI_FILENAME = os.path.join(APPDIR, "cherrypywithsubdirs.ini")


def compile_main_template():
    cheetah = os.path.join(sys.exec_prefix, "scripts", "cheetah")
    if not os.path.isfile(cheetah):
        # oder doch cheetah.py?
        cheetah = os.path.join(sys.exec_prefix, "scripts", "cheetah.py")
    main_template = os.path.join(APPDIR, "main_template.tmpl")
    args = [ sys.executable, cheetah, "compile", "--nobackup", main_template ]
    subprocess.call(args, cwd = APPDIR)


class Root(object):
    
    def default(self, *args, **kwargs):
        """
        Standard-Handler fr Objekte, die keiner anderen Handler-Funktion
        zugewiesen werden konnten.
        
        TMPL-Dateien werden hier auch ohne zugewiesener Funktion abgearbeitet
        und ausgeliefert.
        """
        
        filename = os.path.join(APPDIR, *args)
        
        if os.path.isdir(filename):
            # Handelt es sich um die index.tmpl?
            filename = os.path.join(filename, "index.tmpl")
            if os.path.isfile(filename):
                # Fehlenden Slash anhngen
                request = cherrypy.request
                path_info = request.path_info
                if not path_info.endswith('/'):
                    new_url = cherrypy.url(path_info + '/', request.query_string)
                    raise cherrypy.HTTPRedirect(new_url)
            else:
                raise cherrypy.NotFound()
        else:
            # Benannte Vorlage
            if filename.lower().endswith(".tmpl"):
                if not os.path.isfile(filename):
                    raise cherrypy.NotFound()
            else:
                raise cherrypy.NotFound()
        
        # Vorlage rendern und zurck geben
        template = Template(file = filename)
        template.request = cherrypy.request
        template.response = cherrypy.response
        return str(template)
        
    default.exposed = True


def main():
    
    # Hauptvorlage compilieren
    compile_main_template()
    
    # Anwendung ausfhren
    app = cherrypy.tree.mount(Root(), config = INI_FILENAME)
    cherrypy.config.update({"tools.staticdir.root": APPDIR})
    cherrypy.quickstart(app)


if __name__ == "__main__":
    main()





